/**
 ** regionMapCntrlTaskCodels.c
 **
 ** Codels used by the control task regionMapCntrlTask
 **
 ** Author: 
 ** Date: 
 **
 **/

#include <portLib.h>

#include "server/regionMapHeader.h"


/*------------------------------------------------------------------------
 * regionMapInitCntrl  -  control codel of INIT request Init
 *
 * Description:    just checks that the init params are OK
 * Report: OK
 *                 S_regionMap_BAD_INIT_PARAMS
 *                 S_regionMap_COULD_NOT_ALLOCATE_MAP
 *
 * Returns:    OK or ERROR
 */

STATUS
regionMapInitCntrl(rmapInitParams *initParams, int *report)
{
  if ((initParams->nbX <= 0) || (initParams->nbY <= 0)) {
    fprintf (stderr, "regionMap: the nb of cells %d and %d should be strictly > 0 !\n",
	     initParams->nbX, initParams->nbY);
    *report = S_regionMap_BAD_INIT_PARAMS;
    return ERROR;
  }
  if (initParams->scale <= 0) {
    fprintf (stderr, "regionMap: the scale %f should be strictly > 0 !\n", initParams->scale);
    *report = S_regionMap_BAD_INIT_PARAMS;
    return ERROR;
  }
  if ((initParams->nbX > RMAP_MAX_SIZE_X) 
      || (initParams->nbY > RMAP_MAX_SIZE_Y)) {
    fprintf  (stderr, "regionMap: size parameters (%d, %d) exceed the maximal size (%d, %d)\n",
	      initParams->nbX, initParams->nbY, 
	      RMAP_MAX_SIZE_X, RMAP_MAX_SIZE_Y);
    *report = S_regionMap_BAD_INIT_PARAMS;
    return ERROR;
  }

  return OK;
}

/*------------------------------------------------------------------------
 * regionMapSetSavePeramsCntrl  -  control codel of CONTROL request SetSaveParams
 *
 * Description:    does nothing actually (should check the existence of the
 * directory, but I feel lazy)
 * Report: OK
 *
 * Returns:    OK or ERROR
 */

STATUS
regionMapSetSaveParamsCntrl(rmapSaveParams *saveParams, int *report)
{
  strncpy (SDI_F->saveParams.fileName, saveParams->fileName, RMAP_MAX_STRLEN);
  SDI_F->saveParams.number = saveParams->number;
  
  return OK;
}


